SERVER_URL = 'http://localhost:5000'
WEB_URL = 'http://localhost:5000'
SLACK_BOT_TOKEN = 'XXX'
SLACK_CHANNEL = 'XXX'
AUTH0_DOMAIN = 'XXX'
SENTRY_DSN = 'XXX'
FLOAT_PROJECT_TOKEN = 'XXXX'
SAMPLES_PROJECT_TOKEN = 'XXX'
LABML_VERSION = 'XXX'
ANALYTICS_TO_SERVER = False
IS_LOCAL_SETUP = True
INDICATOR_LIMIT = 100
IS_LOGIN_REQUIRED = True
